==> kafka-3.7.2-src.tgz: kafka-3.7.2-src/clients/src/test/java/org/apache/kafka/common/config/provider/MockVaultConfigProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.common.config.provider;

import java.io.IOException;
import java.io.Reader;
import java.io.StringReader;
import java.util.Map;

public class MockVaultConfigProvider extends FileConfigProvider {

    Map<String, ?> vaultConfigs;
    private boolean configured = false;
    private static final String LOCATION = "location";

    @Override
    protected Reader reader(String path) throws IOException {
        String vaultLocation = (String) vaultConfigs.get(LOCATION);
        return new StringReader("truststoreKey=testTruststoreKey\ntruststorePassword=randomtruststorePassword\n" + "truststoreLocation=" + vaultLocation + "\n");
    }

    @Override
    public void configure(Map<String, ?> configs) {
        this.vaultConfigs = configs;
        configured = true;
    }

    public boolean configured() {
        return configured;
    }
}

==> kafka-3.8.1-src.tgz: kafka-3.8.1-src/clients/src/test/java/org/apache/kafka/common/config/provider/MockVaultConfigProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.common.config.provider;

import java.io.IOException;
import java.io.Reader;
import java.io.StringReader;
import java.nio.file.Path;
import java.util.Map;

public class MockVaultConfigProvider extends FileConfigProvider {

    Map<String, ?> vaultConfigs;
    private boolean configured = false;
    private static final String LOCATION = "location";

    @Override
    protected Reader reader(Path path) throws IOException {
        String vaultLocation = (String) vaultConfigs.get(LOCATION);
        return new StringReader("truststoreKey=testTruststoreKey\ntruststorePassword=randomtruststorePassword\n" + "truststoreLocation=" + vaultLocation + "\n");
    }

    @Override
    public void configure(Map<String, ?> configs) {
        super.configure(configs);
        this.vaultConfigs = configs;
        configured = true;
    }

    public boolean configured() {
        return configured;
    }
}
